@@ -7,8 +7,8 @@
 #ifndef ENTRYFILTERDIALOG_H
 #define ENTRYFILTERDIALOG_H
 
-#include <QScopedPointer>
 #include <QDialog>
+#include <QScopedPointer>
 
 class EntryFilter;
 namespace Ui
@@ -21,7 +21,7 @@ class EntryFilterDialog : public QDialog
     Q_OBJECT
 public:
     explicit EntryFilterDialog(EntryFilter &entryFilter);
-    ~EntryFilterDialog();
+    ~EntryFilterDialog() override;
 
     bool ignoreBlocked() const;
 
