@@ -6,8 +6,8 @@
 #ifndef DASHBOARD_H
 #define DASHBOARD_H
 
-#include "ui_dashboard.h"
 #include "statistics/statisticsmainwindow.h"
+#include "ui_dashboard.h"
 
 #include <KXmlGuiWindow>
 #include <QUrl>
@@ -22,7 +22,6 @@ class ThemedBackgroundRenderer;
 class ImageWidget;
 }
 
-
 class CollectionWidget;
 class RemoveButton;
 
@@ -31,19 +30,19 @@ class Dashboard : public KXmlGuiWindow
     Q_OBJECT
 public:
     explicit Dashboard(ParleyMainWindow *parent);
-    ~Dashboard();
+    ~Dashboard() override;
 
 public slots:
-    void slotOpenUrl(const QUrl& url);
-    void slotPracticeUrl(const QUrl& url);
-    //void slotDoubleClicked(const QModelIndex& index);
+    void slotOpenUrl(const QUrl &url);
+    void slotPracticeUrl(const QUrl &url);
+    // void slotDoubleClicked(const QModelIndex& index);
     void slotDoubleClickOpen();
-    //void updateRecentFilesModel();
+    // void updateRecentFilesModel();
     void populateGrid();
     void populateMap();
     void clearGrid();
-    void slotPracticeButtonClicked(const QString& urlString);
-    void slotRemoveButtonClicked(const QString& urlString);
+    void slotPracticeButtonClicked(const QString &urlString);
+    void slotRemoveButtonClicked(const QString &urlString);
     void statisticsHandler(const QUrl &url);
     void remove(QGridLayout *layout, int row, int column, bool deleteWidgets);
     void deleteChildWidgets(QLayoutItem *item);
@@ -51,7 +50,7 @@ public slots:
 private slots:
     void setTheme();
     void updateWidgets();
-    void backgroundChanged(const QPixmap& pixmap);
+    void backgroundChanged(const QPixmap &pixmap);
     void updateFontColors();
     void updateBackground();
 
@@ -60,16 +59,16 @@ private:
     ParleyMainWindow *m_mainWindow;
     StatisticsMainWindow *m_statisticsWidget;
     Practice::ThemedBackgroundRenderer *m_themedBackgroundRenderer;
-    Practice::ImageWidget* m_widget;
+    Practice::ImageWidget *m_widget;
 
-    QMap<QString, QString> m_recentFilesMap;  // url, name
+    QMap<QString, QString> m_recentFilesMap; // url, name
     QUrl m_openUrl;
     QGridLayout *m_subGridLayout;
     QGridLayout *m_completedGridLayout;
-    QList<CollectionWidget *>  m_collectionWidgets; // List of the widgets in the dashboard.
+    QList<CollectionWidget *> m_collectionWidgets; // List of the widgets in the dashboard.
 
     // The parts of the collections
-    QUrl          m_urlArray[N];
+    QUrl m_urlArray[N];
 
     int m_count;
 };
