@@ -15,17 +15,16 @@ class KEduVocDocument;
 
 namespace Editor
 {
-
 class DeclensionWidget : public QWidget, public Ui::DeclensionWidget
 {
     Q_OBJECT
 
 public:
-    explicit DeclensionWidget(QWidget *parent = 0);
+    explicit DeclensionWidget(QWidget *parent = nullptr);
 
 public slots:
-    void setDocument(KEduVocDocument* doc);
-    void setTranslation(KEduVocExpression* entry, int translation);
+    void setDocument(KEduVocDocument *doc);
+    void setTranslation(KEduVocExpression *entry, int translation);
 
     /**
      * Fill the line edits
@@ -38,20 +37,20 @@ signals:
     void sigModified();
 
 private slots:
-    void textChanged(const QString&);
+    void textChanged(const QString &);
 
 private:
     int currentAdditionalWordFlag();
     void setupLineEdits();
 
-    int m_identifier;
-    KEduVocExpression* m_entry;
-    KEduVocDocument* m_doc;
+    int m_identifier{-1};
+    KEduVocExpression *m_entry{nullptr};
+    KEduVocDocument *m_doc{nullptr};
 
     /**
      * All line edits and labels, index corresponding to KEduVocWordFlag::indexOf
      */
-    QMap< int, QLineEdit* > m_DeclensionLineEdits;
+    QMap<int, QLineEdit *> m_DeclensionLineEdits;
 };
 
 }
