@@ -10,13 +10,9 @@
 #define EDITOR_H
 
 #include "parleydocument.h"
-
-#include "scripts/scripting/parley.h"
-
 #include <KXmlGuiWindow>
 
 class QLineEdit;
-class ScriptManager;
 
 ///@brief contains objects for the editor main window
 
@@ -31,6 +27,7 @@ namespace Editor
 class VocabularyView;
 class LessonView;
 class WordTypeView;
+class AudioWidget;
 class InflectionWidget;
 class ComparisonWidget;
 class SummaryWordWidget;
@@ -42,8 +39,8 @@ class EditorWindow : public KXmlGuiWindow
     Q_OBJECT
 
 public:
-    explicit EditorWindow(ParleyMainWindow* parent);
-    ~EditorWindow();
+    explicit EditorWindow(ParleyMainWindow *parent);
+    ~EditorWindow() override;
 
     /**
      * setup the action (menus etc)
@@ -61,12 +58,12 @@ public:
     /** This will look at the lesson list and also the combo box to determine what should be displayed in the table. */
     void updateTableFilter();
 
-public slots:
-    /**
-     * Load enabled scripts (from configuration parleyrc)
-     */
-    void initScripts();
+    VocabularyView *vocabularyView() const
+    {
+        return m_vocabularyView;
+    }
 
+public slots:
     /**
      * Edit languages contained in the document.
      * This includes adding/removing languages,
@@ -76,11 +73,6 @@ public slots:
 
     void slotConfigShowSearch();
 
-    /**
-     *  Display script manager (open a new window / or Settings window)
-     */
-    void slotShowScriptManager();
-
     void applyPrefs();
 
     /**
@@ -107,48 +99,42 @@ private slots:
     void startSearch();
 
 signals:
-    void signalSetData(const QList<int>& entries, int currentTranslation);
+    void signalSetData(const QList<int> &entries, int currentTranslation);
 
 private:
-    ParleyMainWindow  *m_mainWindow;
+    ParleyMainWindow *m_mainWindow{nullptr};
 
-    QAction* m_vocabShowSearchBarAction;
+    QAction *m_vocabShowSearchBarAction{nullptr};
 
-    VocabularyModel *m_vocabularyModel;
-    VocabularyView *m_vocabularyView;
-    VocabularyFilter *m_vocabularyFilter;
+    VocabularyModel *m_vocabularyModel{nullptr};
+    VocabularyView *m_vocabularyView{nullptr};
+    VocabularyFilter *m_vocabularyFilter{nullptr};
 
-    QLineEdit *m_searchLine;
-    QWidget *m_searchWidget;
-    QAction *m_spellCheckMenu;
+    QLineEdit *m_searchLine{nullptr};
+    QWidget *m_searchWidget{nullptr};
+    QAction *m_spellCheckMenu{nullptr};
 
     /** Show a single conjugation and let the user edit it */
-    InflectionWidget *m_inflectionWidget;
-    SummaryWordWidget *m_summaryWordWidget;
-    ComparisonWidget *m_comparisonWidget;
-    LatexWidget *m_latexWidget;
-    SynonymWidget *m_synonymWidget;
-    SynonymWidget *m_antonymWidget;
-    SynonymWidget *m_falseFriendWidget;
+    InflectionWidget *m_inflectionWidget{nullptr};
+    SummaryWordWidget *m_summaryWordWidget{nullptr};
+    ComparisonWidget *m_comparisonWidget{nullptr};
+    LatexWidget *m_latexWidget{nullptr};
+    SynonymWidget *m_synonymWidget{nullptr};
+    SynonymWidget *m_antonymWidget{nullptr};
+    SynonymWidget *m_falseFriendWidget{nullptr};
+    AudioWidget *m_audioWidget{nullptr};
 
     /// dock widgets to display lessons, word types, ...
-    LessonView *m_lessonView;
-    LessonModel *m_lessonModel;
+    LessonView *m_lessonView{nullptr};
+    LessonModel *m_lessonModel{nullptr};
 
-    WordClassModel *m_wordTypeModel;
-    WordTypeView *m_wordTypeView;
+    WordClassModel *m_wordTypeModel{nullptr};
+    WordTypeView *m_wordTypeView{nullptr};
 
-    ScriptManager* m_scriptManager;
-
-    ///stores all the translations of a vocabulary word
-    Translator* m_translator;
-
-    QList<QDockWidget*> m_dockWidgets;
+    QList<QDockWidget *> m_dockWidgets;
     QList<bool> m_dockWidgetVisibility;
 
     friend class ::ParleyDocument;
-    friend class Scripting::Parley;
-    friend class ::ScriptManager;
 };
 
 }
