@@ -5,11 +5,14 @@
 
 #include "lessonview.h"
 
-#include <QAction>
+#include "vocabularymodel.h"
+#include "vocabularyview.h"
+
 #include <KActionCollection>
-#include <QInputDialog>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <QAction>
+#include <QInputDialog>
 
 #include <KEduVocExpression>
 #include <KEduVocLesson>
@@ -19,7 +22,9 @@
 
 using namespace Editor;
 
-LessonView::LessonView(EditorWindow * parent) : ContainerView(parent)
+LessonView::LessonView(EditorWindow *parent)
+    : ContainerView(parent)
+    , m_editorWindow(parent)
 {
     QAction *actionNewLesson = new QAction(this);
     parent->actionCollection()->addAction(QStringLiteral("new_lesson"), actionNewLesson);
@@ -33,7 +38,7 @@ LessonView::LessonView(EditorWindow * parent) : ContainerView(parent)
     parent->actionCollection()->addAction(QStringLiteral("rename_lesson"), actionRenameLesson);
     actionRenameLesson->setText(i18n("Rename Unit"));
     actionRenameLesson->setIcon(QIcon::fromTheme(QStringLiteral("edit-rename")));
-//    actionRenameLesson->setWhatsThis(i18n("Rename the selected unit"));
+    //    actionRenameLesson->setWhatsThis(i18n("Rename the selected unit"));
     actionRenameLesson->setToolTip(actionRenameLesson->whatsThis());
     actionRenameLesson->setStatusTip(actionRenameLesson->whatsThis());
 
@@ -48,11 +53,19 @@ LessonView::LessonView(EditorWindow * parent) : ContainerView(parent)
     QAction *actionSplitLesson = new QAction(this);
     parent->actionCollection()->addAction(QStringLiteral("split_lesson"), actionSplitLesson);
     actionSplitLesson->setText(i18n("Split Unit into Smaller Units"));
-    actionSplitLesson->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy")));  /// @todo better icon
+    actionSplitLesson->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy"))); /// @todo better icon
     actionSplitLesson->setWhatsThis(i18n("Make multiple smaller units out of one big unit."));
     actionSplitLesson->setToolTip(actionSplitLesson->whatsThis());
     actionSplitLesson->setStatusTip(actionSplitLesson->whatsThis());
 
+    QAction *actionMoveToNewLesson = new QAction(this);
+    parent->actionCollection()->addAction(QStringLiteral("move_to_new_lesson"), actionMoveToNewLesson);
+    actionMoveToNewLesson->setText(i18n("Move to new lesson"));
+    actionMoveToNewLesson->setIcon(QIcon::fromTheme(QStringLiteral("edit-move")));
+    actionMoveToNewLesson->setWhatsThis(i18n("Moves the selected vocabulary to a new lesson"));
+    actionMoveToNewLesson->setToolTip(actionMoveToNewLesson->whatsThis());
+    actionMoveToNewLesson->setStatusTip(actionMoveToNewLesson->whatsThis());
+
     QAction *actionRemoveGradesLesson = new QAction(this);
     parent->actionCollection()->addAction(QStringLiteral("remove_grades_lesson"), actionRemoveGradesLesson);
     actionRemoveGradesLesson->setText(i18n("Remove Confidence Levels"));
@@ -89,6 +102,7 @@ LessonView::LessonView(EditorWindow * parent) : ContainerView(parent)
     connect(actionRenameLesson, &QAction::triggered, this, &LessonView::slotRename);
     connect(actionDeleteLesson, &QAction::triggered, this, &LessonView::slotDeleteLesson);
     connect(actionSplitLesson, &QAction::triggered, this, &LessonView::slotSplitLesson);
+    connect(actionMoveToNewLesson, &QAction::triggered, this, &LessonView::moveToNewLesson);
     connect(actionRemoveGradesLesson, &QAction::triggered, this, &LessonView::slotRemoveGradesLesson);
     connect(actionRemoveGradesLessonChildren, &QAction::triggered, this, &LessonView::slotRemoveGradesLessonChildren);
     connect(actionExpandAll, &QAction::triggered, this, &LessonView::expandAllLesson);
@@ -98,7 +112,7 @@ LessonView::LessonView(EditorWindow * parent) : ContainerView(parent)
     addAction(actionNewLesson);
     addAction(actionRenameLesson);
     addAction(actionDeleteLesson);
-    QAction* separator = new QAction(this);
+    QAction *separator = new QAction(this);
     separator->setSeparator(true);
     addAction(separator);
     addAction(actionRemoveGradesLesson);
@@ -111,12 +125,12 @@ LessonView::LessonView(EditorWindow * parent) : ContainerView(parent)
     addAction(actionCollapseAll);
 }
 
-void LessonView::currentChanged(const QModelIndex & current, const QModelIndex & previous)
+void LessonView::currentChanged(const QModelIndex &current, const QModelIndex &previous)
 {
     QTreeView::currentChanged(current, previous);
 
     if (current.isValid()) {
-        KEduVocLesson *container = static_cast<KEduVocLesson*>(current.internalPointer());
+        KEduVocLesson *container = static_cast<KEduVocLesson *>(current.internalPointer());
         if (container) {
             emit selectedLessonChanged(container);
             emit signalShowContainer(container);
@@ -124,7 +138,7 @@ void LessonView::currentChanged(const QModelIndex & current, const QModelIndex &
     }
 }
 
-void LessonView::selectionChanged(const QItemSelection & selected, const QItemSelection & deselected)
+void LessonView::selectionChanged(const QItemSelection &selected, const QItemSelection &deselected)
 {
     QTreeView::selectionChanged(selected, deselected);
 
@@ -132,13 +146,13 @@ void LessonView::selectionChanged(const QItemSelection & selected, const QItemSe
         return;
     }
 
-    KEduVocLesson *container = static_cast<KEduVocLesson*>(selected.indexes().value(0).internalPointer());
+    KEduVocLesson *container = static_cast<KEduVocLesson *>(selected.indexes().value(0).internalPointer());
     if (container) {
         emit selectedLessonChanged(container);
     }
 }
 
-void LessonView::setTranslation(KEduVocExpression * entry, int translation)
+void LessonView::setTranslation(KEduVocExpression *entry, int translation)
 {
     Q_UNUSED(translation)
 
@@ -164,7 +178,7 @@ void LessonView::slotCreateNewLesson()
 
     scrollTo(modelIndex);
     selectionModel()->setCurrentIndex(modelIndex, QItemSelectionModel::ClearAndSelect);
-    edit(modelIndex);    // let the user type a new name for the lesson
+    edit(modelIndex); // let the user type a new name for the lesson
 }
 
 void LessonView::slotDeleteLesson()
@@ -176,12 +190,16 @@ void LessonView::slotDeleteLesson()
         return;
     }
 
-    KEduVocLesson* lesson = static_cast<KEduVocLesson*>(selectedIndex.internalPointer());
+    KEduVocLesson *lesson = static_cast<KEduVocLesson *>(selectedIndex.internalPointer());
 
     int count = lesson->entryCount(KEduVocLesson::Recursive);
 
-    if (count == 0 ||
-            KMessageBox::warningYesNo(this, i18np("There is %1 word left in this unit. Do you want to delete it?", "There are %1 words left in this unit. Do you want to delete them?", count)) == KMessageBox::Yes) {
+    if (count == 0
+        || KMessageBox::warningYesNo(this,
+                                     i18np("There is %1 word left in this unit. Do you want to delete it?",
+                                           "There are %1 words left in this unit. Do you want to delete them?",
+                                           count))
+            == KMessageBox::Yes) {
         m_model->deleteContainer(selectedIndex);
     }
 }
@@ -195,7 +213,15 @@ void LessonView::slotSplitLesson()
     /** @todo A nicer dialog would be great.
      * Maybe with radio buttons to ask, if the entries should be in random order or as they come. */
     bool ok = false;
-    int numEntries = QInputDialog::getInt(this,  i18n("Entries per Unit"), i18n("The unit will be split into smaller unit. How many entries in each unit do you want?"), Prefs::entriesPerLesson(), 1, 1000, 1, &ok);
+    int numEntries = QInputDialog::getInt(this,
+                                          i18n("Entries per Unit"),
+                                          i18n("The unit will be split into smaller unit. How many entries in each unit do you want?"),
+                                          Prefs::entriesPerLesson(),
+                                          1,
+                                          1000,
+                                          1,
+                                          &ok);
+
     if (!ok) {
         return;
     }
@@ -204,10 +230,26 @@ void LessonView::slotSplitLesson()
     setExpanded(selectionModel()->currentIndex(), true);
 }
 
+void LessonView::moveToNewLesson()
+{
+    const QModelIndexList indexes = m_editorWindow->vocabularyView()->getSelectedIndexes();
+    if (indexes.isEmpty()) {
+        return;
+    }
+
+    KEduVocDocument *doc = m_model->document();
+    KEduVocLesson *lesson = new KEduVocLesson(i18n("New Lesson"), doc->lesson());
+    doc->lesson()->appendChildContainer(lesson);
+
+    for (const QModelIndex &index : indexes) {
+        lesson->appendEntry(qvariant_cast<KEduVocExpression *>(index.data(VocabularyModel::EntryRole)));
+    }
+}
+
 void LessonView::slotRemoveGradesLesson()
 {
     QModelIndex selectedIndex = selectionModel()->currentIndex();
-    KEduVocLesson* lesson = static_cast<KEduVocLesson*>(selectedIndex.internalPointer());
+    KEduVocLesson *lesson = static_cast<KEduVocLesson *>(selectedIndex.internalPointer());
     lesson->resetGrades(-1, KEduVocContainer::NotRecursive);
     emit signalShowContainer(lesson);
 }
@@ -215,12 +257,12 @@ void LessonView::slotRemoveGradesLesson()
 void LessonView::slotRemoveGradesLessonChildren()
 {
     QModelIndex selectedIndex = selectionModel()->currentIndex();
-    KEduVocLesson* lesson = static_cast<KEduVocLesson*>(selectedIndex.internalPointer());
+    KEduVocLesson *lesson = static_cast<KEduVocLesson *>(selectedIndex.internalPointer());
     lesson->resetGrades(-1, KEduVocContainer::Recursive);
     emit signalShowContainer(lesson);
 }
 
-void LessonView::setModel(LessonModel * model)
+void LessonView::setModel(LessonModel *model)
 {
     m_model = model;
     ContainerView::setModel(model);
