@@ -25,7 +25,6 @@ class WordClassModel;
 
 namespace Editor
 {
-
 /**
 * Represents the overview of a KEduVocExpression
 * Shows the language word
@@ -41,30 +40,30 @@ class SummaryWordWidget : public QWidget, public Ui::SummaryWordWidget
     Q_OBJECT
 
 public:
-    SummaryWordWidget(VocabularyFilter *model, const std::shared_ptr<KEduVocDocument> &, QWidget *parent = 0);
+    SummaryWordWidget(VocabularyFilter *model, const std::shared_ptr<KEduVocDocument> &, QWidget *parent = nullptr);
 
 public slots:
     /**
-    * Sets the selected word (KEduVocExpression) from the vocabularyView
-    */
+     * Sets the selected word (KEduVocExpression) from the vocabularyView
+     */
     void setTranslation(KEduVocExpression *entry, int translation);
 
     /**
-    * Called when a KEduVocDocument change happened
-    */
+     * Called when a KEduVocDocument change happened
+     */
     void slotDocumentChanged(const std::shared_ptr<KEduVocDocument> &doc);
 
     /**
-    * Called when the selection changed in the vocabulary view
-    */
+     * Called when the selection changed in the vocabulary view
+     */
     void slotSelectionChanged(const QItemSelection &, const QItemSelection &);
 
-    void wordTypeSelected(const QString& wordTypeName);
+    void wordTypeSelected(const QString &wordTypeName);
 
 private:
     /**
-    * Clears the form and the comboboxes
-    */
+     * Clears the form and the comboboxes
+     */
     void clear();
 
     /**
@@ -73,27 +72,27 @@ private:
     void populateLessonList(KEduVocExpression *entry);
     */
     /**
-    * Fill the word types list with the available word types of the KEduVocDocument
-    */
+     * Fill the word types list with the available word types of the KEduVocDocument
+     */
     void setCurrentWordType(KEduVocExpression *entry, int translation);
 
 private:
-    VocabularyFilter *m_model;
+    VocabularyFilter *m_model{nullptr};
     std::shared_ptr<KEduVocDocument> m_doc;
-    QDataWidgetMapper *m_mapper;
-    WordClassModel *m_wordTypeModel;
-    QTreeView *m_wordTypeView;
-    KEduVocExpression *m_entry;
-    int m_translationId;
+    QDataWidgetMapper *m_mapper{nullptr};
+    WordClassModel *m_wordTypeModel{nullptr};
+    QTreeView *m_wordTypeView{nullptr};
+    KEduVocExpression *m_entry{nullptr};
+    int m_translationId{0};
 };
 
 class SummaryWordDelegate : public QItemDelegate
 {
     Q_OBJECT
 public:
-    explicit SummaryWordDelegate(QObject *parent = 0);
+    explicit SummaryWordDelegate(QObject *parent = nullptr);
 
-    void setEditorData(QWidget *editor, const QModelIndex &index) const Q_DECL_OVERRIDE;
+    void setEditorData(QWidget *editor, const QModelIndex &index) const override;
 };
 }
 
