@@ -12,28 +12,22 @@
 
 #include "parleydocument.h"
 
-#include <KXmlGuiWindow>
 #include "practice/sessionmanagercontinuous.h"
 #include "practice/sessionmanagerfixed.h"
+#include <KXmlGuiWindow>
 
 #include <QPointer>
 
-
 class KRecentFilesAction;
-#if 0
-
-class Dashboard;
-#endif
-
 
 class ParleyMainWindow : public KXmlGuiWindow
 {
     Q_OBJECT
 
 public:
-    static ParleyMainWindow * instance();
+    static ParleyMainWindow *instance();
 
-    ~ParleyMainWindow();
+    ~ParleyMainWindow() override;
 
     /** enum for the different components that can be displayed */
     enum Component {
@@ -42,7 +36,7 @@ public:
         EditorComponent,
         ConfigurePracticeComponent,
         PracticeComponent,
-        PracticeSummary
+        PracticeSummary,
     };
 
     /**
@@ -66,10 +60,12 @@ public:
      * Return the ParleyDocument member object
      * @return member m_document
      */
-    ParleyDocument* parleyDocument();
+    ParleyDocument *parleyDocument();
 
     Component currentComponent();
 
+    QSize sizeHint() const override;
+
 public slots:
     /** Updates connections when the ParleyDocument pointer is changed to @p doc **/
     void documentUpdated(const std::shared_ptr<KEduVocDocument> &doc);
@@ -81,13 +77,11 @@ public slots:
     void slotUpdateWindowCaption();
 
     /** When quitting, ask for confirmation if the doc has not been saved */
-    bool queryClose() Q_DECL_OVERRIDE;
+    bool queryClose() override;
 
     /** remove an entry from the list of recent files */
     void removeRecentFile(const QUrl &url);
 
-    QSize sizeHint() const Q_DECL_OVERRIDE;
-
     /** set up options */
     void slotGeneralOptions();
     void slotApplyPreferences();
@@ -100,30 +94,19 @@ public slots:
     void showPracticeSummary();
     void practiceFinished();
 
-
-    /**
-     * Show the tip of the day (force it to be shown)
-     */
-    void tipOfDay();
-
-    /**
-     * Show the tip of the day - the startup version that can be disabled
-     */
-    void startupTipOfDay();
-
     void showDashboard();
     void showEditor();
     void showPractice();
     void showPracticeConfiguration();
 
-    void switchComponent(Component component);
+    void switchComponent(ParleyMainWindow::Component component);
 
     /**
      * Shows or hides actions that are only relevant when a document is opened
      */
     void showDocumentActions(bool open, bool edit);
 
-    void setVisibleToolbar(const QString& name);
+    void setVisibleToolbar(const QString &name);
 
 signals:
     void recentFilesChanged();
@@ -133,21 +116,20 @@ private:
     ParleyMainWindow(const QUrl &filename = QUrl());
     static ParleyMainWindow *s_instance;
 
-    Component      m_currentComponent;
-    KXmlGuiWindow *m_currentComponentWindow;
+    Component m_currentComponent;
+    KXmlGuiWindow *m_currentComponentWindow{nullptr};
 
-    KRecentFilesAction *m_recentFilesAction;
+    KRecentFilesAction *m_recentFilesAction{nullptr};
 
     /** m_document is the current vocabulary document. */
-    ParleyDocument   *m_document;
+    ParleyDocument *m_document{nullptr};
 
     Component m_componentBeforePractice;
 
+    // Practice::SessionManagerContinuous m_sessionManager;
+    Practice::SessionManagerFixed m_sessionManager;
 
-    //Practice::SessionManagerContinuous m_sessionManager;
-    Practice::SessionManagerFixed        m_sessionManager;
-
-    friend int main(int argc, char* argv[]);
+    friend int main(int argc, char *argv[]);
 };
 
 #endif // PARLEYMAINWINDOW_H
