@@ -8,17 +8,17 @@
 #include <QTimer>
 
 #include <KColorScheme>
-#include <QDebug>
 #include <KLocalizedString>
+#include <QDebug>
 
 #include "ui_practice_mainwindow.h"
 
-#include "settings/kgametheme/kgametheme.h"
 #include "comparisonmodewidget.h"
 #include "conjugationmodewidget.h"
 #include "flashcardmodewidget.h"
 #include "mixedlettersmodewidget.h"
 #include "multiplechoicemodewidget.h"
+#include "settings/kgametheme/kgametheme.h"
 #include "themedbackgroundrenderer.h"
 #include "writtenpracticewidget.h"
 
@@ -28,12 +28,8 @@ GuiFrontend::GuiFrontend(QWidget *parent)
     : AbstractFrontend(parent)
     , m_widget(new ImageWidget())
     , m_ui(new Ui::PracticeMainWindow())
-    , m_modeWidget(nullptr)
     , m_resultState(AbstractFrontend::AnswerWrong)
     , m_feedbackState(AbstractFrontend::AnswerWrong)
-    , m_currentBox(0)
-    , m_newBoxIfCorrect(0)
-    , m_newBoxIfWrong(0)
     , m_themedBackgroundRenderer(new ThemedBackgroundRenderer(this, QStringLiteral("practicethemecache.bin")))
 {
     m_widget->setScalingEnabled(false, false);
@@ -74,7 +70,7 @@ QVariant GuiFrontend::userInput()
     return m_modeWidget->userInput();
 }
 
-QWidget* GuiFrontend::widget()
+QWidget *GuiFrontend::widget()
 {
     return m_widget;
 }
@@ -85,7 +81,7 @@ void GuiFrontend::setMode(Mode mode)
     AbstractModeWidget *newWidget = 0;
     switch (mode) {
     case Written:
-        if (/*m_modeWidget->metaObject()->className() == QLatin1String("WrittenPracticeWidget")*/false) {
+        if (/*m_modeWidget->metaObject()->className() == QLatin1String("WrittenPracticeWidget")*/ false) {
             qDebug() << "Written practice widget is already the central widget";
             break;
         }
@@ -122,18 +118,16 @@ void GuiFrontend::setMode(Mode mode)
     updateFontColors();
 }
 
-void GuiFrontend::setLessonName(const QString& lessonName)
+void GuiFrontend::setLessonName(const QString &lessonName)
 {
-    m_ui->lessonLabel->setText(i18nc("Display of the current unit during practice", "Unit: %1",
-                                     lessonName));
+    m_ui->lessonLabel->setText(i18nc("Display of the current unit during practice", "Unit: %1", lessonName));
 }
 
 void GuiFrontend::showGrade(int preGrade, int grade)
 {
     if (preGrade == 0 && grade == 0) {
         m_ui->gradeLabel->setText(i18n("New word"));
-    }
-    else {
+    } else {
         m_ui->gradeLabel->setText(i18nc("Display of the current confidence level during practice, 1st param is either initial or long term",
                                         "%1, confidence %2",
                                         grade == 0 ? i18n("initial") : i18n("long term"),
@@ -158,7 +152,7 @@ void GuiFrontend::showSolution()
     m_ui->hintButton->setEnabled(false);
     setImage(m_solutionImage);
 }
-void GuiFrontend::setSynonym(const QString& entry)
+void GuiFrontend::setSynonym(const QString &entry)
 {
     m_modeWidget->setSynonym(entry);
 }
@@ -204,7 +198,9 @@ void GuiFrontend::setFinishedWordsTotalWords(int finished, int total)
     m_ui->totalProgress->setValue(finished);
     m_ui->totalProgress->setToolTip(i18np("You answered correctly %2 of a total of %1 word.\nYou are %3% done.",
                                           "You answered correctly %2 of a total of %1 words.\nYou are %3% done.",
-                                          total, finished, finishedPercentage));
+                                          total,
+                                          finished,
+                                          finishedPercentage));
 }
 
 QFont GuiFrontend::knownLangFont() const
@@ -217,64 +213,62 @@ QFont GuiFrontend::learningLangFont() const
     return m_learningLangFont;
 }
 
-void GuiFrontend::setKnownLangFont(const QFont& font)
+void GuiFrontend::setKnownLangFont(const QFont &font)
 {
     m_knownLangFont = font;
 }
 
-void GuiFrontend::setLearningLangFont(const QFont& font)
+void GuiFrontend::setLearningLangFont(const QFont &font)
 {
     m_learningLangFont = font;
 }
 
-
-void GuiFrontend::setHint(const QVariant& hint)
+void GuiFrontend::setHint(const QVariant &hint)
 {
     m_modeWidget->setHint(hint);
 }
 
-void GuiFrontend::setQuestion(const QVariant& question)
+void GuiFrontend::setQuestion(const QVariant &question)
 {
     m_modeWidget->setQuestion(question);
 }
 
-
-void GuiFrontend::setQuestionPronunciation(const QString& pronunciationText)
+void GuiFrontend::setQuestionPronunciation(const QString &pronunciationText)
 {
     m_modeWidget->setQuestionPronunciation(pronunciationText);
 }
 
-void GuiFrontend::setQuestionSound(const QUrl& soundUrl)
+void GuiFrontend::setQuestionSound(const QUrl &soundUrl)
 {
     m_modeWidget->setQuestionSound(soundUrl);
 }
 
-void GuiFrontend::setSolution(const QVariant& solution)
+void GuiFrontend::setSolution(const QVariant &solution)
 {
     m_modeWidget->setSolution(solution);
 }
 
-void GuiFrontend::setQuestionImage(const QUrl& image)
+void GuiFrontend::setQuestionImage(const QUrl &image)
 {
     m_questionImage = image;
 }
 
-void GuiFrontend::setSolutionImage(const QUrl& image)
+void GuiFrontend::setSolutionImage(const QUrl &image)
 {
     m_solutionImage = image;
 }
 
-void GuiFrontend::setQuestionFont(const QFont& font)
+void GuiFrontend::setQuestionFont(const QFont &font)
 {
     m_modeWidget->setQuestionFont(font);
 }
 
-void GuiFrontend::setSolutionFont(const QFont& font)
+void GuiFrontend::setSolutionFont(const QFont &font)
 {
     m_modeWidget->setSolutionFont(font);
 }
 
-void GuiFrontend::setImage(const QUrl& image)
+void GuiFrontend::setImage(const QUrl &image)
 {
     if (m_lastImage == image) {
         return;
@@ -288,17 +282,17 @@ void GuiFrontend::setImage(const QUrl& image)
     m_lastImage = image;
 }
 
-void GuiFrontend::setSolutionPronunciation(const QString& pronunciationText)
+void GuiFrontend::setSolutionPronunciation(const QString &pronunciationText)
 {
     m_modeWidget->setSolutionPronunciation(pronunciationText);
 }
 
-void GuiFrontend::setSolutionSound(const QUrl& soundUrl)
+void GuiFrontend::setSolutionSound(const QUrl &soundUrl)
 {
     m_modeWidget->setSolutionSound(soundUrl);
 }
 
-void GuiFrontend::setFeedback(const QVariant& feedback)
+void GuiFrontend::setFeedback(const QVariant &feedback)
 {
     m_modeWidget->setFeedback(feedback);
 }
@@ -312,32 +306,32 @@ void GuiFrontend::setFeedbackState(ResultState feedbackState)
 void GuiFrontend::setResultState(ResultState resultState)
 {
     // TODO: temporary text labels instead of graphics
-//    m_ui->statusImageLabel->setFont(QFont("", 80, QFont::Bold));
+    //    m_ui->statusImageLabel->setFont(QFont("", 80, QFont::Bold));
     m_ui->statusToggle->setResultState(resultState);
     switch (resultState) {
     case AbstractFrontend::QuestionState:
     case AbstractFrontend::AnswerSynonym:
-//        m_ui->statusImageLabel->setText("?");
-//        m_ui->toggleButton->setEnabled(false);
-//        m_ui->toggleButton->setText(QString(0x2717)+QChar(0x2192)+QChar(0x2713));
+        //        m_ui->statusImageLabel->setText("?");
+        //        m_ui->toggleButton->setEnabled(false);
+        //        m_ui->toggleButton->setText(QString(0x2717)+QChar(0x2192)+QChar(0x2713));
         m_ui->boxesWidget->setBoxes(m_currentBox);
         break;
     case AbstractFrontend::AnswerCorrect:
-//        m_ui->statusImageLabel->setText(QChar(0x2713));
-//        m_ui->toggleButton->setEnabled(true);
-//        m_ui->toggleButton->setText(QString(0x2713)+QChar(0x2192)+QChar(0x2717));
+        //        m_ui->statusImageLabel->setText(QChar(0x2713));
+        //        m_ui->toggleButton->setEnabled(true);
+        //        m_ui->toggleButton->setText(QString(0x2713)+QChar(0x2192)+QChar(0x2717));
         m_ui->boxesWidget->setBoxes(m_newBoxIfCorrect, m_currentBox);
         break;
 
-//        m_ui->statusImageLabel->setText("?");
-//        m_ui->toggleButton->setEnabled(true);
-//        m_ui->toggleButton->setText(QString(0x2713)+QChar(0x2192)+QChar(0x2717));
-//        m_ui->boxesWidget->setBoxes(m_currentBox);
-//        break;
+        //        m_ui->statusImageLabel->setText("?");
+        //        m_ui->toggleButton->setEnabled(true);
+        //        m_ui->toggleButton->setText(QString(0x2713)+QChar(0x2192)+QChar(0x2717));
+        //        m_ui->boxesWidget->setBoxes(m_currentBox);
+        //        break;
     case AbstractFrontend::AnswerWrong:
-//        m_ui->statusImageLabel->setText(QChar(0x2717));
-//        m_ui->toggleButton->setEnabled(true);
-//        m_ui->toggleButton->setText(QString(0x2717)+QChar(0x2192)+QChar(0x2713));
+        //        m_ui->statusImageLabel->setText(QChar(0x2717));
+        //        m_ui->toggleButton->setEnabled(true);
+        //        m_ui->toggleButton->setText(QString(0x2717)+QChar(0x2192)+QChar(0x2713));
         m_ui->boxesWidget->setBoxes(m_newBoxIfWrong, m_currentBox);
         break;
     }
