@@ -12,7 +12,6 @@
 
 namespace Practice
 {
-
 class ThemedBackgroundRenderer;
 class StatusToggleButton;
 
@@ -21,8 +20,8 @@ class StatusToggle : public ImageWidget
     Q_OBJECT
 
 public:
-    explicit StatusToggle(QWidget* parent = 0);
-    QSize minimumSizeHint() const Q_DECL_OVERRIDE;
+    explicit StatusToggle(QWidget *parent = nullptr);
+    QSize minimumSizeHint() const override;
 
     void setRenderer(ThemedBackgroundRenderer *renderer);
     void setResultState(AbstractFrontend::ResultState state);
@@ -34,10 +33,10 @@ signals:
     void toggle();
 
 private:
-    ThemedBackgroundRenderer *m_renderer;
+    ThemedBackgroundRenderer *m_renderer{nullptr};
 
-    StatusToggleButton *m_toggle;
-    QAction *m_toggleAction;
+    StatusToggleButton *m_toggle{nullptr};
+    QAction *m_toggleAction{nullptr};
 
     AbstractFrontend::ResultState m_resultState;
 
