@@ -11,15 +11,14 @@
 #include "imagecache.h"
 #include <QFuture>
 #include <QFutureWatcher>
-#include <QTimer>
 #include <QSvgRenderer>
+#include <QTimer>
 
 class QMargins;
 class KGameTheme;
 
 namespace Practice
 {
-
 class ThemedBackgroundRenderer : public QObject
 {
     Q_OBJECT
@@ -29,7 +28,7 @@ public:
         NoScale,
         Horizontal,
         Vertical,
-        Rect
+        Rect,
     };
 
     enum Edge {
@@ -37,7 +36,7 @@ public:
         Bottom,
         Left,
         Right,
-        Center
+        Center,
     };
 
     enum Align {
@@ -48,23 +47,23 @@ public:
         RightBottom // right or bottom (depending on orientation of the edge)
     };
 
-    ThemedBackgroundRenderer(QObject* parent, const QString& cacheFilename);
-    ~ThemedBackgroundRenderer();
+    ThemedBackgroundRenderer(QObject *parent, const QString &cacheFilename);
+    ~ThemedBackgroundRenderer() override;
 
-    void setTheme(const QString& theme);
+    void setTheme(const QString &theme);
 
-    QSizeF getSizeForId(const QString& id);
-    QRectF getRectForId(const QString& id);
-    QPixmap getPixmapForId(const QString& id, QSize size = QSize());
+    QSizeF getSizeForId(const QString &id);
+    QRectF getRectForId(const QString &id);
+    QPixmap getPixmapForId(const QString &id, QSize size = QSize());
     QMargins contentMargins();
 
     QPixmap getScaledBackground();
 
-    QColor fontColor(const QString& context, const QColor& fallback);
+    QColor fontColor(const QString &context, const QColor &fallback);
 
 public Q_SLOTS:
     void clearRects();
-    void addRect(const QString& name, const QRect& rect);
+    void addRect(const QString &name, const QRect &rect);
     void updateBackground();
 
     void updateBackgroundTimeout();
@@ -76,20 +75,29 @@ signals:
 
 private:
     QImage renderBackground(bool fastScale);
-    void renderRect(const QString& name, const QRect& rect, QPainter *p, bool fastScale);
-    void renderItem(const QString& idBase, const QString& idSuffix, const QRect& rect, QPainter *p, bool fastScale, ScaleBase scaleBase, Qt::AspectRatioMode aspectRatio, Edge edge, Align align, bool inside);
-    QRect scaleRect(QRectF itemRect, const QRect& baseRect, ScaleBase scaleBase, Qt::AspectRatioMode aspectRatio);
-    QRect alignRect(QRect itemRect, const QRect& baseRect, Edge edge, Align align, bool inside);
+    void renderRect(const QString &name, const QRect &rect, QPainter *p, bool fastScale);
+    void renderItem(const QString &idBase,
+                    const QString &idSuffix,
+                    const QRect &rect,
+                    QPainter *p,
+                    bool fastScale,
+                    ScaleBase scaleBase,
+                    Qt::AspectRatioMode aspectRatio,
+                    Edge edge,
+                    Align align,
+                    bool inside);
+    QRect scaleRect(QRectF itemRect, const QRect &baseRect, ScaleBase scaleBase, Qt::AspectRatioMode aspectRatio);
+    QRect alignRect(QRect itemRect, const QRect &baseRect, Edge edge, Align align, bool inside);
 
     ImageCache m_cache;
     QFuture<QImage> m_future;
     QFutureWatcher<QImage> m_watcher;
-    KGameTheme *m_theme;
+    KGameTheme *m_theme{nullptr};
     QHash<QString, QString> m_rectMappings;
     QSvgRenderer m_renderer;
-    QList<QPair<QString, QRect> > m_rects;
-    QList<QPair<QString, QRect> > m_lastScaledRenderRects; // the rects used for the last scaled render
-    QList<QPair<QString, QRect> > m_lastFullRenderRects; // the rects used for the last full render
+    QList<QPair<QString, QRect>> m_rects;
+    QList<QPair<QString, QRect>> m_lastScaledRenderRects; // the rects used for the last scaled render
+    QList<QPair<QString, QRect>> m_lastFullRenderRects; // the rects used for the last full render
     bool m_haveCache;
     bool m_queuedRequest;
     bool m_isFastScaledRender;
