@@ -10,17 +10,14 @@
 #include <KConfigWidgets/KConfigDialog>
 
 /**
-  *@author Peter Hedlund
-*/
+ *@author Peter Hedlund
+ */
 
 class GeneralOptions;
 class ViewOptions;
-class PasteOptions;
-class PluginOptions;
-
+class TranslationShellOptions;
 class KEduVocDocument;
 class KComboBox;
-
 class KConfigSkeleton;
 
 class ParleyPrefs : public KConfigDialog
@@ -37,36 +34,35 @@ protected slots:
     /**
      * Called when the user clicks Apply or OK.
      */
-    void updateSettings() Q_DECL_OVERRIDE;
+    void updateSettings() override;
     /**
      * Updates dialog widgets. Here only used after loading a profile.
      * Profiles only store the settings of the last three pages in the dialog.
      */
-    void updateWidgets() Q_DECL_OVERRIDE;
+    void updateWidgets() override;
     /**
      * Called when the user clicks Default
      */
-    void updateWidgetsDefault() Q_DECL_OVERRIDE;
+    void updateWidgetsDefault() override;
 
 protected:
     /**
      * Returns true if the current state of the dialog is different from the saved settings
      */
-    bool hasChanged() Q_DECL_OVERRIDE;
+    bool hasChanged() override;
     /**
      * Returns true if the current state of the dialog represents the default settings.
      */
-    bool isDefault() Q_DECL_OVERRIDE;
+    bool isDefault() override;
 
 private:
-    GeneralOptions * m_generalOptions;
-    ViewOptions * m_viewOptions;
-    PasteOptions * m_pasteOptions;
-    PluginOptions * m_pluginOptions;
+    GeneralOptions *m_generalOptions{nullptr};
+    ViewOptions *m_viewOptions{nullptr};
+    TranslationShellOptions *m_translationShellOptions{nullptr};
 
-    KConfigSkeleton *m_config;
-    KEduVocDocument *m_doc;
-    KComboBox       *m_lessons;
+    KConfigSkeleton *m_config{nullptr};
+    KEduVocDocument *m_doc{nullptr};
+    KComboBox *m_lessons{nullptr};
 };
 
 #endif
