@@ -8,7 +8,8 @@
 
 #include <QCheckBox>
 
-ViewOptions::ViewOptions(QWidget *parent) : QWidget(parent)
+ViewOptions::ViewOptions(QWidget *parent)
+    : QWidget(parent)
 {
     setupUi(this);
 }
