@@ -1,43 +1,33 @@
-/**************************************************************************
-    Copyright 2007-2010 Frederik Gladhorn <gladhorn@kde.org>
-***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007-2010 Frederik Gladhorn <gladhorn@kde.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "conjugationoptions.h"
 
-#include "languagesettings.h"
 #include "documentsettings.h"
+#include "languagesettings.h"
 #include "prefs.h"
 
 #include <KEduVocDocument>
 
 #include <KLocalizedString>
-#include <QStackedLayout>
 #include <QLabel>
+#include <QStackedLayout>
 #include <QTreeWidget>
 
 ConjugationOptions::ConjugationOptions(KEduVocDocument *doc, QWidget *parent)
     : QWidget(parent)
     , m_doc(doc)
-    , m_language(0)
 {
     m_treeWidget = new QTreeWidget(this);
     m_treeWidget->setHeaderLabel(i18n("Tenses"));
     m_treeWidget->setRootIsDecorated(false);
-    QHBoxLayout* layout = new QHBoxLayout(this);
+    QHBoxLayout *layout = new QHBoxLayout(this);
     layout->addWidget(m_treeWidget);
     layout->setContentsMargins(0, 0, 0, 0);
     setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding);
-    connect(m_treeWidget, &QTreeWidget::itemChanged,
-            this, &ConjugationOptions::processCheckBoxChanged);
+    connect(m_treeWidget, &QTreeWidget::itemChanged, this, &ConjugationOptions::processCheckBoxChanged);
 }
 
 void ConjugationOptions::setLanguages(int from, int to)
@@ -60,9 +50,10 @@ void ConjugationOptions::setupTenses()
     documentSettings.load();
     QStringList activeTenses = documentSettings.conjugationTenses();
     qDebug() << "activeTenses:" << activeTenses << " id tenses: " << m_doc->identifier(m_language).tenseList();
-    QTreeWidgetItem* tenseItem;
+    QTreeWidgetItem *tenseItem;
 
-    foreach(const QString & tenseName, m_doc->identifier(m_language).tenseList()) {
+    const QStringList tenses = m_doc->identifier(m_language).tenseList();
+    for (const QString &tenseName : tenses) {
         tenseItem = new QTreeWidgetItem(m_treeWidget);
         tenseItem->setText(0, tenseName);
         if (activeTenses.contains(tenseName)) {
@@ -109,4 +100,3 @@ void ConjugationOptions::processCheckBoxChanged(QTreeWidgetItem *item, int colum
         emit checkBoxChanged();
     }
 }
-
